@@ -99,8 +99,6 @@ def _parse_font_entry_win(name, font, fonts):
     :param name: The font name
     :param font: The font file path
     :param fonts: The pygame font dictionary
-
-    :return: Tuple of (bold, italic, name)
     """
     true_type_suffix = "(TrueType)"
     mods = ("demibold", "narrow", "light", "unicode", "bt", "mt")
@@ -186,16 +184,19 @@ def _font_finder_darwin():
 
 def initsysfonts_darwin():
     """Read the fonts on MacOS, and OS X."""
-    # if the X11 binary exists... try and use that.
-    #  Not likely to be there on pre 10.4.x ... or MacOS 10.10+
-    if exists("/usr/X11/bin/fc-list"):
-        fonts = initsysfonts_unix("/usr/X11/bin/fc-list")
-    # This fc-list path will work with the X11 from the OS X 10.3 installation
-    # disc
-    elif exists("/usr/X11R6/bin/fc-list"):
-        fonts = initsysfonts_unix("/usr/X11R6/bin/fc-list")
-    else:
-        # eventually this should probably be the preferred solution
+    #  fc-list is not likely to be there on pre 10.4.x, or MacOS 10.10+
+    fonts = {}
+
+    fclist_locations = [
+        "/usr/X11/bin/fc-list",  # apple x11
+        "/usr/X11R6/bin/fc-list",  # apple x11
+    ]
+    for bin_location in fclist_locations:
+        if exists(bin_location):
+            fonts = initsysfonts_unix(bin_location)
+            break
+
+    if len(fonts) == 0:
         fonts = _font_finder_darwin()
 
     return fonts
@@ -474,7 +475,7 @@ def get_fonts():
     return list(Sysfonts)
 
 
-def match_font(name, bold=0, italic=0):
+def match_font(name, bold=False, italic=False):
     """pygame.font.match_font(name, bold=0, italic=0) -> name
     find the filename for the named system font
 
